@@ -2,40 +2,32 @@ from django.conf import settings
 
 import boto3
 
-SERVICE_NAME = 'ecs'
-CONTAINER_DEFAULT_NAME = 'gunicorn'
-COMMAND_NAME = 'run_task'
-
 
 class AWSECSHandler:
     """AWS ECS service handler."""
 
+    service_name = 'ecs'
+
     def __init__(self):
         """Constructor."""
         self.client = boto3.client(
-            service_name=SERVICE_NAME,
+            service_name=self.service_name,
             aws_access_key_id=settings.AWS_ACCESS_KEY_ID,
             aws_secret_access_key=settings.AWS_SECRET_ACCESS_KEY,
             region_name=settings.AWS_DEFAULT_REGION,
         )
-        self.container_default_name = CONTAINER_DEFAULT_NAME
-        self.command_name = COMMAND_NAME
+        self.container_default_name = getattr(
+            settings, 'ECS_CONTAINER_NAME', 'gunicorn')
+        self.command_name = getattr(
+            settings, 'COMMAND_NAME', 'run_task')
 
-    def run_task(
-            self,
-            command=None,
-            launch_type=settings.AWS_CLUSTER_LAUNCH,
-            cluster=settings.AWS_CLUSTER,
-            task_definition=settings.AWS_TASK_DEFINITION,
-            logging=settings.AWS_LOGGING,
-            logConfiguration=settings.AWS_LOGGING_CONFIGURATION):
+    def run_task(self, command=None, **kwargs):
         """Run Task definition on ECS Cluster."""
         run_kwargs = {
-            'cluster': cluster,
-            'launchType': launch_type,
-            'taskDefinition': task_definition,
-            'logging': logging,
-            'logConfiguration': logConfiguration
+            'cluster': settings.AWS_CLUSTER,
+            'launchType': settings.AWS_CLUSTER_LAUNCH,
+            'taskDefinition': settings.AWS_TASK_DEFINITION,
+            **kwargs,
         }
 
         if command:
