@@ -3,6 +3,7 @@ from django.conf import settings
 
 import boto3
 
+
 class AWSSQSHandler:
     """AWS ECS service handler."""
 
@@ -22,7 +23,11 @@ class AWSSQSHandler:
             MessageBody=json.dumps(data),
             **kwargs
         )
-    
-    def delete_message(self, queue_url, receipt_handle, **kwargs):
+
+    def delete_message(self, queue_url, receipt_handle):
         return self.client.delete_message(
-            QueueUrl=queue_url, ReceiptHandle=receipt_handle)
\ No newline at end of file
+            QueueUrl=queue_url, ReceiptHandle=receipt_handle)
+
+    def delete_message_batch(self, queue_url, entries):
+        return self.client.delete_message_batch(
+            QueueUrl=queue_url, Entries=entries)
